<div align="center"> 

![](.media/icon-128x128_round.png)

# Royal Spells

Meaningless fantasy spell stats generator

</div>

## Links

[![PyPI](https://img.shields.io/pypi/v/royalspells)](https://pypi.org/project/royalspells)
